#
# spec file for package sysprof
#
# Copyright (c) 2019 SUSE LLC.
# Copyright (c) 2016 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 3

Name:           sysprof
Version:        3.34.1
Release:        2.32
Summary:        A system-wide Linux profiler
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Development/Tools/Debuggers
URL:            https://wiki.gnome.org/Apps/Sysprof
Source0:        http://download.gnome.org/sources/sysprof/3.34/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM sysprof-libsysprof-ui-avoid-use-of-env.patch -- Avoid use of env
Patch0:         sysprof-libsysprof-ui-avoid-use-of-env.patch

BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  itstool
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.50.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.61.3
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libdazzle-1.0) >= 3.30.0
BuildRequires:  pkgconfig(libsystemd) >= 222
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.105
BuildRequires:  pkgconfig(systemd)
Requires:       hicolor-icon-theme
%{?systemd_requires}

%description
Sysprof is a sampling CPU profiler for Linux that collects accurate,
high-precision data and provides efficient access to the sampled
calltrees.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package capture-devel-static
Summary:        Library to read and write syspref's capture format
Group:          Development/Tools/Debuggers

%description capture-devel-static
This static library allows external tooling to read and write the
syspref's capture format.

%lang_package

%prep
%autosetup -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file org.gnome.Sysprof%{sover} Profiling

%check
### FIXME ### Temp disabled during 3.34 devel period
#%%meson_test

%pre
%service_add_pre sysprof%{sover}.service
%service_add_pre sysprof2.service

%preun
%service_del_preun sysprof%{sover}.service
%service_del_preun sysprof2.service

%post
/sbin/ldconfig
%service_add_post sysprof%{sover}.service
%service_add_post sysprof2.service

%postun
/sbin/ldconfig
%service_del_postun sysprof%{sover}.service
%service_del_postun sysprof2.service

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/sysprof
%{_bindir}/sysprof-cli
%{_datadir}/applications/*.desktop
%{_datadir}/dbus-1/interfaces/org.gnome.Sysprof2.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Sysprof%{sover}.Profiler.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Sysprof%{sover}.Service.xml
%dir %{_datadir}/dbus-1/system.d
%{_datadir}/dbus-1/system.d/org.gnome.Sysprof2.conf
%{_datadir}/dbus-1/system.d/org.gnome.Sysprof%{sover}.conf
%{_datadir}/dbus-1/system-services/org.gnome.Sysprof2.service
%{_datadir}/dbus-1/system-services/org.gnome.Sysprof%{sover}.service
%{_datadir}/glib-2.0/schemas/org.gnome.sysprof%{sover}.gschema.xml
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/metainfo/org.gnome.Sysprof%{sover}.appdata.xml
%{_datadir}/mime/packages/sysprof-mime.xml
%{_datadir}/polkit-1/actions/org.gnome.sysprof%{sover}.policy
%{_libdir}/libsysprof-%{sover}.so
%{_libdir}/libsysprof-ui-%{sover}.so
%{_libexecdir}/sysprofd
%{_unitdir}/sysprof2.service
%{_unitdir}/sysprof%{sover}.service
%dir %{_datadir}/help/C/sysprof
%doc %{_datadir}/help/C/sysprof/*

%files devel
%doc AUTHORS TODO
%{_includedir}/sysprof-%{sover}/
%{_libdir}/pkgconfig/sysprof-%{sover}.pc
%{_libdir}/pkgconfig/sysprof-ui-%{sover}.pc

%files capture-devel-static
%{_libdir}/libsysprof-capture-%{sover}.a
%{_libdir}/pkgconfig/sysprof-capture-%{sover}.pc

%files lang -f %{name}.lang

%changelog
* Tue Nov 19 2019 bjorn.lie@gmail.com
- Add sysprof-libsysprof-ui-avoid-use-of-env.patch: libsysprof-ui:
  avoid use of environ for -Werror=shadow.
* Mon Oct  7 2019 bjorn.lie@gmail.com
- Update to version 3.34.1:
  + Process search fixes.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Help fixes.
  + Build and test fixes.
  + Updated translations.
- Require meson >= 0.50.0.
* Thu Sep  5 2019 luke@ljones.dev
- Update to version 3.33.92:
  + Check for GLib 2.61.3 or newer for features used when removing
    deprecated API usage from GLib.
  + Require meson 0.50
  + Updated translations.
* Thu Aug 15 2019 bjorn.lie@gmail.com
- Update to version 3.33.90:
  + Tweak CSS styling a bit.
  + Hide RAPL rows if no counters were discovered.
  + Fix --no-battery in sysprof-cli.
  + Improve parsing of /proc/mounts and /proc/pid/mountinfo.
  + Improve support for using libsysprof from Flatpak.
  + Symbol directories are removed from public ABI and consumers
    should now add directories to SysprofElfSymbolResolver
    directly.
- Changes from version 3.33.4:
  + Build system fixes and improved backports.
  + New network, disk, battery, and energy sources.
  + Additional options for sysprof-cli including "syprof-cli
  - -command" support.
  + i18n is now properly initialized at startup.
  + Improved styling.
  + A new "duplex" graph type for read/write type visuals.
- Changes from version 3.33.3:
  + This release of Sysprof contains the largest amount of work
    since we revived the project a few years ago. We have revamped
    and minimized the ABI of libsysprof-ui considerably. As port of
    the ABI update, symbols have been changed from Sp to Sysprof to
    reduce chances of collisions.
  + With these changes comes a soname bump and upgrade of the D-Bus
    API provided by the package. Some work has been taken to
    implement older versions of the sysprofd API so that older
    clients may continue to work.
  + Various build system improvements.
  + A new libsysprof-capture-3.a capture library has been provided
    to allow application developers to capture data and merge into
    the profiler stream.
  + The recording and viewing API has been redesigned and improved.
  + Sysprof has been backported to support GTK 3.22 and GLib 2.50.
  + Support for passing file-descriptors has been added to allow
    profiling integration with GNOME Shell, GJS, and GTK profilers.
  + New API to allow integration with external tooling that spawns
    applications is provided so that environment and arguments may
    be modified.
  + A new re-record feature has been added.
  + The capture format can now store log messages, metadata, and
    file content.
  + A new org.gnome.Sysprof3 daemon has been added, which is
    written using GDBus instead of libsystemd. This may improve
    portability to some distributions.
  + The portability of Sysprof to non-Linux systems has been
    improved, however many recording features are still not
    available on non-Linux platforms.
  + A new org.gnome.Sysprof3.Profiler XML D-Bus interface is
    provided for tooling that wants to export Sysprof content via
    D-Bus.
  + Various new capture sources have been provided.
  + sysprofd also implements a compat org.gnome.Sysprof2 D-Bus
    end-point for older clients.
  + Updated translations.
- Add pkgconfig(glib-2.0) and pkgconfig(libdazzle-1.0)
  BuildRequires: New dependencies.
* Fri Aug  2 2019 mliska@suse.cz
- Use FAT LTO objects in order to provide proper static library.
* Mon May 13 2019 dimstar@opensuse.org
- Replace systemd-gtk BuildRequires with pkgconfig(systemd): make
  the build cheaper by not having to wait for the 'real' systemd
  package to have built, but allow to use systemd-mini. The change
  in the stack causing this was polkit dropping its hard dep on
  systemd.
* Sat May 11 2019 bjorn.lie@gmail.com
- Add systemd-gtk BuildRequires: Now needed due to changes
  elsewhere in the stack.
* Wed Mar 13 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Updated translations.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Handle cancellation during profiler startup more gracefully.
* Thu Feb 14 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + A new memory source for basic memory statistics. This is meant
    for overview only, not precise details.
  + Fix a small memory leak.
  + Allow disabling memory/cpu sources from sysprof-cli.
  + CSS styling updates.
  + Updated icon for GNOME 3.32 icon initiative.
  + The line visualizer can auto-discover Y axis range.
  + Build system improvements.
  + Updated translations.
- Update URL to https://wiki.gnome.org/Apps/Sysprof.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Remove app-menu in favor of window-menu, following GNOME design
    guidelines for 3.32.
  + Fixes for i18n/l10n.
  + Build fixes to avoid use of non-portable __WORDSIZE.
  + Updated translations.
- Add meson_test macro in check section, run tests.
* Fri Nov  2 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + The profiler menu button more properly handles changes to the
    toplevel window.
  + Fixes for i18n/l10n intialization.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Various compilation fixes for alternative platforms, compilers,
    and toolchains.
  + Backport model filter fixes from libdazzle.
  + Updated translations.
* Wed Sep 12 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Fix incorrect free func for GPtrArray.
  + Various build system improvements.
  + ENABLE_POLKIT is now repsected in the kallsyms support.
  + suggested-action fixes for CSS.
  + Updated translations.
- Drop sysprof-fix-incorrect-free-func.patch (fixed upstream).
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Thu Jun 21 2018 luc14n0@linuxmail.org
- Update to version 3.29.3:
  + Experimental tracking of various drm events (vblank and
    CRTC/MSC).
  + Drawing code now uses double instead of float for additional
    precision.
  + CLOCK_MONOTONIC is now the preferred clock.
  + A new capture type of "mark" has been added to the capture
    format. It supports an event name with a duration >= 0.
  + Various counters are automatically detected and displayed when
    opening a capture file.
  + A new in-tree tool "sysprof-cat" which can join multiple
    capture files together gracefully.
  + Fix a number of situations where cpu/pid were crossed.
  + Updated translations.
- Drop explicit gettext BuildRequires: meson doesn't look for it.
* Wed Apr 11 2018 luc14n0@linuxmail.org
- Update to version 3.28.1:
  + Updated translations.
- Add hicolor-icon-theme BuildRequires for directory ownership
  purposes.
- Drop:
  + binutils-devel, gobject-introspection-devel and libxml2-tools
    BuildRequires packages: they are no longer required nor used
    anymore.
  + desktop_database_* and icon_theme_cache_* post/postun
    scriptlets: their functionality has been moved to RPM file
    triggers (version 4.13, suse_version 1330).
* Wed Mar 14 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + SpCaptureWriter now pre-initializes the scratch buffer to zero
    to pacify valgrind.
  + Updated translations.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Updated translations.
- Drop sysprof-drop-debug-code.patch: fixed upstream.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb 21 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Sysprof now exclusively uses the meson build system.
  + Improvements to the process filtering model used in the
    profiler popover.
  + More tests for utility helpers.
  + Some code was relicensed to LGPLv2.1+ to extend it's
    reusability.
  + A new libsysprof-capture-2.a static library is installed to
    allow external tooling to read and write the capture format.
    We expect tooling such as GJS to use this in the future.
  + A new kallsyms tokenizer was added.
  + If we fail to parse kallsyms as the effective user, we now
    query the sysprofd daemon to access and parse those symbols for
    us as root. This requires polkit authorization on the DBus
    connection just like our elevated perf_event_open() helper.
  + Now that we have to deal with overlapping kernel and user-space
    memory, Sysprof tries harder to check the current perf context.
    New API was added to symbol resolvers to facilitate this.
- Split out new subpackage sysprof-capture-devel-static.
- Use meson build system, following upstreams change:
  + Add meson BuildRequires.
  + Use meson/meson_build/meson_install instead of
    configure/make/make_install.
- Add sysprof-drop-debug-code.patch: Fix build on i586 by removing
  lingering debug code.
* Thu Oct  5 2017 dimstar@opensuse.org
- Update to version 3.26.1:
  + Add missing FAQ to help documentation.
* Sat Sep 16 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + No changes, stable bump only.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Additional help topics.
  + Fix for a potential divide-by-zero when generating callgraphs.
  + Alignment attributes to allow building on armel/armhf/mipsel.
  + About dialog is now modal.
  + Each new Sysprof window gets its own window group.
  + Updated translations.
* Tue Apr 25 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + About dialog is now modal to it's direct parent only.
  + Updated translations.
* Mon Mar 20 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Use gtk_show_uri_on_window() to improve help window placement
    on Wayland.
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Compilation fix for 32-bit ARM.
  + Updated translations.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Various compilation checks based on results from ARM builders.
  + Support for setting symbol directories to affect symbol
    resolution.
  + Translate paths from /newroot/ into the host filesystem when
    possible. This should allow some degree of profiling
    container-based applications and still resolve symbols on the
    host. Builder does this now when profiling Flatpak-based
    applications.
  + Updated translations.
* Sat Feb 18 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Build system support for Meson.
  + Appdata support has been added.
  + Desktop file can be translated.
  + Updated translations.
* Wed Nov 30 2016 zaitor@opensuse.org
- Update to version 3.22.3:
  + Fix expansion of function text in callgraph.
  + Fix jump-to-function in callees list.
  + Disable record button while generating callgraph profile.
  + Ensure sysprof icons are available form libsysprof-ui-2.
  + sysprof-cli requires --force to overwrite previous capture.
  + Reduce code duplication in capture frame initialization.
  + Updated translations.
* Wed Nov  2 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + ftruncate() when creating a capture in case we overwrite a
    previous capture file. This ensures we don't leave junk at the
    end of the capture.
  + Handle EAGAIN when writing the opportunistic end-time header.
  + Capture cursor should short circuit when no read delegate was
    found.
  + Updated translations.
* Sat Oct 15 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + A new data source called "hostinfo" has been added. It records
    various CPU datapoints as "counters" in the sysprof capture.
  + A new visualizers abstraction has been added so that we can
    start providing new ways to look at profiler data.
  + A CPU visualizer has been added which renders datapoints
    recorded from the hostinfo data source.
  + Selecting ranges of the visualizer will update the callgraph
    limiting stacktrace samples, to the given time range.
  + Missing headers are now installed which may be needed by
    applications using libsysprof-ui.
  + A keyboard shortcuts dialog has been added.
  + A theme manager has been added to allow us to provide custom
    CSS for various themes. Currently, we have additional styling
    added for Adwaita and Adwaita-dark.
  + Updated translations.
- Pass --disable-Werror to configure, we do not need to handle
  warnings as errors.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Fri Sep  2 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Allow collapsing the callgraph tree with Left arrow.
  + Add a full barrier before writing data_tail as suggested by
    Perf kernel documentation.
  + Support for additional architectures has been enabled by the
    use of C11 atomics.
  + Require -std=gnu11 for stdatomic.h.
  + Correct gettext domain for translation files.
- Drop sysprof-correct-gettext-domain.patch: Fixed upstream.
* Sat Aug 27 2016 zaitor@opensuse.org
- Initial package, version 3.21.90.
